@@ -18,8 +18,8 @@ class CLI:
                 foo='foo value'
             ),
         ),target)
-    def gencode(self,src,dst,tmpl=DEFAULT_MAKER_FILE,overwrite=False):
-        return gencode(src,dst,tmpl,overwrite=overwrite)
+    def gencode(self,src,dst,maker=DEFAULT_MAKER_FILE,overwrite=False,exists_ok=True):
+        return gencode(src,dst,maker,overwrite=overwrite,exists_ok=exists_ok)
 
 def main():
     fire.Fire(CLI())
